diff --git tests/phpunit/tests/user/query.php tests/phpunit/tests/user/query.php
index 9abf99d..dbd378a 100644
--- tests/phpunit/tests/user/query.php
+++ tests/phpunit/tests/user/query.php
@@ -686,4 +686,23 @@ class Tests_User_Query extends WP_UnitTestCase {
 		$this->assertContains( $users[1], $found );
 		$this->assertNotContains( $users[2], $found );
 	}
+
+	public function test_who_public_authors() {
+
+		$users = $this->factory->user->create_many( 3 );
+
+		$this->factory->post->create( array( 'post_author' => $users[0], 'post_status' => 'publish', 'post_type' => 'post' ) );
+		$this->factory->post->create( array( 'post_author' => $users[1], 'post_status' => 'publish', 'post_type' => 'post' ) );
+
+		$q = new WP_User_Query( array(
+			'who' => 'public_authors',
+		) );
+
+		$found = wp_list_pluck( $q->get_results(), 'ID' );
+
+		$this->assertEquals( 2, $q->get_total() );
+
+		$this->assertContains( $users[0], $found );
+		$this->assertContains( $users[1], $found );
+	}
 }

diff --git src/wp-includes/user.php src/wp-includes/user.php
index e602a3e..3f33d5b 100644
--- src/wp-includes/user.php
+++ src/wp-includes/user.php
@@ -555,7 +555,7 @@ class WP_User_Query {
 	 *                                         of fields. Accepts 'ID', 'display_name', 'login', 'nicename', 'email',
 	 *                                         'url', 'registered'. Use 'all' for all fields and 'all_with_meta' to
 	 *                                         include meta fields. Default 'all'.
 	 *     @type string       $who             Type of users to query. Accepts 'authors'. Default empty (all users).
 	 * }
 	 */
 	public function prepare_query( $query = array() ) {
@@ -631,10 +631,18 @@ class WP_User_Query {
 			$blog_id = absint( $qv['blog_id'] );
 		}
 
-		if ( isset( $qv['who'] ) && 'authors' == $qv['who'] && $blog_id ) {
-			$qv['meta_key'] = $wpdb->get_blog_prefix( $blog_id ) . 'user_level';
-			$qv['meta_value'] = 0;
-			$qv['meta_compare'] = '!=';
+		if ( isset( $qv['who'] ) && $blog_id ) {
+
+			if ( 'authors' == $qv['who'] ) {
+				$qv['meta_key'] = $wpdb->get_blog_prefix( $blog_id ) . 'user_level';
+				$qv['meta_value'] = 0;
+				$qv['meta_compare'] = '!=';
+			} else if ( 'public_authors' == $qv['who'] ) {
+
+				$post_types = get_post_types( array( 'public' => true ) );
+				$this->query_where .= " AND $wpdb->users.ID IN ( SELECT DISTINCT $wpdb->posts.post_author FROM $wpdb->posts WHERE $wpdb->posts.post_status = 'publish' AND $wpdb->posts.post_type IN ( '" . join( "', '", $post_types ) . "' ) )";
+			}
+
 			$qv['blog_id'] = $blog_id = 0; // Prevent extra meta query
 		}
 
@@ -555,7 +555,7 @@ class WP_User_Query {
 	 *                                         'url', 'registered'. Use 'all' for all fields and 'all_with_meta' to
 	 *                                         include meta fields. Default 'all'.
-	 *     @type string       $who             Type of users to query. Accepts 'authors'. Default empty (all users).
+	 *     @type string       $who             Type of users to query. Accepts 'authors', 'public_author'. Default empty (all users).
 	 * }
 	 */